==> nine_lifes-1.7%2B1.21.6-sources.jar: com/bleudev/nine_lifes/custom/effect/AmethysmEffect.java <==
package com.bleudev.nine_lifes.custom.effect;

import com.bleudev.nine_lifes.custom.CustomDamageTypes;
import com.bleudev.nine_lifes.custom.CustomEffects;
import com.bleudev.nine_lifes.networking.payloads.StartAmethysmScreenEffectPayload;
import net.fabricmc.fabric.api.networking.v1.ServerPlayNetworking;
import net.minecraft.class_1291;
import net.minecraft.class_1294;
import net.minecraft.class_1309;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_4081;
import net.minecraft.class_5131;
import java.util.Objects;

public class AmethysmEffect extends class_1291 {
    private int ticks;
    private class_1309 entity;

    public AmethysmEffect() {
        super(class_4081.field_18273, 0xff00ff);
    }

    @Override
    public boolean method_5552(int duration, int amplifier) {
        return true;
    }

    @Override
    public boolean method_5572(class_3218 world, class_1309 entity, int amplifier) {
        if (!world.field_9236) {
            ticks++;
            this.entity = entity;
            if (!entity.method_6113()) {
                if (ticks % 20 == 0)
                    entity.method_64397(world, CustomDamageTypes.of(world, CustomDamageTypes.AMETHYSM_DAMAGE_TYPE), 1f);
                entity.method_18800(0, 0.1, 0);
                entity.field_6037 = true;
            }
            entity.method_5834(true);
        }

        return true;
    }

    @Override
    public void method_52520(class_1309 entity, int amplifier) {
        super.method_52520(entity, amplifier);

        if (entity instanceof class_3222 player) try {
            ServerPlayNetworking.send(player, new StartAmethysmScreenEffectPayload(Objects.requireNonNull(player.method_6112(CustomEffects.AMETHYSM)).method_5584()));
        } catch (NullPointerException ignored) {}

        ticks = 0;
        this.entity = entity;
    }

    @Override
    public void method_5562(class_5131 attributeContainer) {
        super.method_5562(attributeContainer);
        if (!entity.method_6059(class_1294.field_5912))
            entity.method_5834(false);
    }
}

==> nine_lifes-1.9.0%2B1.21.9-sources.jar: com/bleudev/nine_lifes/custom/effect/AmethysmEffect.java <==
package com.bleudev.nine_lifes.custom.effect;

import com.bleudev.nine_lifes.custom.CustomDamageTypes;
import com.bleudev.nine_lifes.custom.CustomEffects;
import com.bleudev.nine_lifes.networking.payloads.StartAmethysmScreenEffect;
import net.fabricmc.fabric.api.networking.v1.ServerPlayNetworking;
import net.minecraft.class_1291;
import net.minecraft.class_1294;
import net.minecraft.class_1309;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_4081;
import net.minecraft.class_5131;
import java.util.Objects;

public class AmethysmEffect extends class_1291 {
    private int ticks;
    private class_1309 entity;

    public AmethysmEffect() {
        super(class_4081.field_18273, 0xff00ff);
    }

    @Override
    public boolean method_5552(int duration, int amplifier) {
        return true;
    }

    @Override
    public boolean method_5572(class_3218 world, class_1309 entity, int amplifier) {
        if (!world.method_8608()) {
            ticks++;
            this.entity = entity;
            if (!entity.method_6113()) {
                if (ticks % 20 == 0)
                    entity.method_64397(world, CustomDamageTypes.of(world, CustomDamageTypes.AMETHYSM_DAMAGE_TYPE), 1f);
                entity.method_18800(0, 0.1, 0);
                entity.field_6037 = true;
            }
            entity.method_5834(true);
        }
        return true;
    }

    @Override
    public void method_52520(class_1309 entity, int amplifier) {
        super.method_52520(entity, amplifier);

        ticks = 0;
        this.entity = entity;

        if (entity instanceof class_3222 player) try {
            ServerPlayNetworking.send(player, new StartAmethysmScreenEffect(Objects.requireNonNull(player.method_6112(CustomEffects.AMETHYSM)).method_5584()));
        } catch (NullPointerException ignored) {}
    }

    @Override
    public void method_5562(class_5131 attributeContainer) {
        super.method_5562(attributeContainer);
        if (!entity.method_6059(class_1294.field_5912))
            entity.method_5834(false);
    }
}
